<?php

namespace Drupal\Tests\webform_browserinfo\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests the webform_browserinfo JavaScript functionalities.
 *
 * @group webform_browserinfo
 */
class WebformBrowserinfoJsTest extends WebDriverTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'webform',
    'webform_ui',
    'webform_browserinfo',
    'webform_browserinfo_test',
  ];

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests whether the browser info is injected into the Webform field.
   */
  public function testJsFieldInjection(): void {
    $this->drupalGet('/webform/test_webform_browserinfo');
    $session = $this->assertSession();
    $session->hiddenFieldExists('webform_browserinfo');
    $driver = $this->getSession()->getDriver();
    $testAttributes = [
      'url:',
      '/webform/test_webform_browserinfo',
      'userAgent:',
      'language:',
      'windowSize:',
      'screenSize:',
      'jsEnabled: true',
      'cookiesEnabled:',
    ];
    foreach ($testAttributes as $attribute) {
      $attributeSearch = $driver->evaluateScript('document.getElementsByClassName("webform-browserinfo")[0].value.includes("' . $attribute . '");');
      $this->assertTrue($attributeSearch);
    }
  }

}
